set linesize 32000
set pagesize 1000
set long 2000000000
set longchunksize 1000
set head off;
set verify off;
set termout off;
 
column u new_value us noprint;
column n new_value ns noprint;
 
select name n from v$database;
select user u from dual;
set sqlprompt &ns:&us>

set head on
set echo on
set termout on
set trimspool on

spool &ns.compareplans3.log

-- 1000 executions or more
-- get rid of sql's that have profiles.

column END_INTERVAL_TIME format a25

drop table allqueries;

create table allqueries as
select
sql_id,
sum(ELAPSED_TIME_DELTA)/1000000 total_elapsed_scnds,
sum(EXECUTIONS_DELTA) total_executions
from DBA_HIST_SQLSTAT s
where
PLAN_HASH_VALUE > 0 and
module='JDBC Thin Client' and
0=
(select count(*)
from dba_hist_sqlstat i
where
i.SQL_PROFILE is not null and
i.sql_id=s.sql_id)
group by sql_id;

drop table orderedqueries;

create table orderedqueries as
select
rownum query_num,
sql_id,
total_elapsed_scnds
from 
(select
sql_id,
total_elapsed_scnds
from allqueries
where total_executions >= 1000
order by total_elapsed_scnds desc);

-- select * from orderedqueries order by query_num;

drop table sumbyplan;

create table sumbyplan as
select
oq.query_num,
ss.SQL_ID,
ss.PLAN_HASH_VALUE,
avg(ss.OPTIMIZER_COST) OPTIMIZER_COST,
sum(ss.EXECUTIONS_DELTA) EXECUTIONS_DELTA,
sum(ss.FETCHES_DELTA) FETCHES_DELTA,
sum(ss.SORTS_DELTA) SORTS_DELTA,
sum(ss.DISK_READS_DELTA) DISK_READS_DELTA,
sum(ss.BUFFER_GETS_DELTA) BUFFER_GETS_DELTA,
sum(ss.ROWS_PROCESSED_DELTA) ROWS_PROCESSED_DELTA,
sum(ss.CPU_TIME_DELTA) CPU_TIME_DELTA,
sum(ss.ELAPSED_TIME_DELTA) ELAPSED_TIME_DELTA,
sum(ss.IOWAIT_DELTA) IOWAIT_DELTA,
sum(ss.DIRECT_WRITES_DELTA) DIRECT_WRITES_DELTA,
sum(ss.PHYSICAL_READ_REQUESTS_DELTA) PHYSICAL_READ_REQUESTS_DELTA,
sum(ss.PHYSICAL_WRITE_REQUESTS_DELTA) PHYSICAL_WRITE_REQUESTS_DELTA
from 
DBA_HIST_SQLSTAT ss,
orderedqueries oq
where
ss.sql_id=oq.sql_id
group by 
oq.query_num,
ss.SQL_ID,
ss.PLAN_HASH_VALUE;

select 
query_num,
SQL_ID,
PLAN_HASH_VALUE,
EXECUTIONS_DELTA executions,
ELAPSED_TIME_DELTA/EXECUTIONS_DELTA avg_elapsed,
OPTIMIZER_COST,
FETCHES_DELTA/EXECUTIONS_DELTA avg_fetches,
SORTS_DELTA/EXECUTIONS_DELTA avg_sorts,
DISK_READS_DELTA/EXECUTIONS_DELTA avg_disk_reads,
BUFFER_GETS_DELTA/EXECUTIONS_DELTA avg_buffer_gets,
ROWS_PROCESSED_DELTA/EXECUTIONS_DELTA avg_rows,
CPU_TIME_DELTA/EXECUTIONS_DELTA avg_cpu,
IOWAIT_DELTA/EXECUTIONS_DELTA avg_iowait,
DIRECT_WRITES_DELTA/EXECUTIONS_DELTA avg_direct_writes,
PHYSICAL_READ_REQUESTS_DELTA/EXECUTIONS_DELTA avg_phys_reads,
PHYSICAL_WRITE_REQUESTS_DELTA/EXECUTIONS_DELTA avg_phys_writes
from
sumbyplan
where
EXECUTIONS_DELTA > 0
order by
query_num,
SQL_ID,
executions desc;


spool off
